import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import ButtonContent from './ButtonContent';

import isNullOrEmpty from '../../isNullOrEmpty';
import getRootClassName from './utils/getRootClassName';
import { iconShape } from './utils/propTypes';


export default ({
    block,
    displayName,
    uiPropDefaultType = PropTypes.string,
    uiPropDefaultValue = '',
    uiPropGetValue = (ui) => ui
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    const Content = ButtonContent({ block, displayName: `${displayName}Content` });

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            children: PropTypes.node,
            disabled: PropTypes.bool,
            icon: iconShape,
            onClick: PropTypes.func,
            target: PropTypes.string,
            to: PropTypes.string,
            ui: uiPropDefaultType
        },

        getDefaultProps() {
            return {
                children: null,
                icon: null,
                onClick: (/* evt */) => {},
                target: null,
                to: '',
                ui: uiPropDefaultValue
            };
        },

        onClick(evt) {
            const { disabled, onClick } = this.props;
            if (disabled) {
                return evt.preventDefault();
            }

            onClick(evt);
        },

        render() {
            const { children, disabled, icon, target, to, ui, ...rest } = this.props;
            return (
                <a
                    { ...rest }
                    className={ getRootClassName(block, { children, icon, ui: uiPropGetValue(ui) }, { disabled }) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    target={ target }>
                    <Content
                        icon={ icon }>
                        { children }
                    </Content>
                </a>
            );
        }

    });

};
