import test from 'tape';

import getScrollTopExpanded from './getScrollTopExpanded';


const getOptions = () => {
    return [
        {
            disabled: false,
            text: 'A',
            value: 'a'
        },
        {
            disabled: false,
            text: 'B',
            value: 'b'
        },
        {
            disabled: false,
            text: 'C',
            value: 'c'
        }
    ];
};

const getHeight = (components) => (value) => {
    return components[value].offsetHeight;
};

test('should return current scroll top if no selected value', (t) => {
    const components = {
        options: {
            scrollTop: 0
        }
    };

    const result = getScrollTopExpanded('', getOptions(), components, getHeight(components));

    t.is(result, 0);
    t.end();
});

test('should return current scroll top if no component for selected value', (t) => {
    const components = {
        options: {
            scrollTop: 0
        }
    };

    const result = getScrollTopExpanded('b', getOptions(), components, getHeight(components));

    t.is(result, 0);
    t.end();
});

test('should center selected value', (t) => {
    const components = {
        0: {
            offsetHeight: 20
        },
        1: {
            offsetHeight: 20
        },
        2: {
            offsetHeight: 20
        },
        options: {
            clientHeight: 40,
            scrollTop: 0
        }
    };

    const result = getScrollTopExpanded('b', getOptions(), components, getHeight(components));

    t.is(result, 10);
    t.end();
});
